@@ -303,14 +303,14 @@ class Dominus:
 
             # Validate on first call
             if not _VALIDATED:
-                from .helpers.core import verify_token_with_server, health_check_all
+                from .helpers.core import verify_token_format, health_check_all
 
-                # Verify token
-                await verify_token_with_server(_TOKEN, _BASE_URL)
+                # Basic token format check
+                verify_token_format(_TOKEN)
 
-                # Health check
+                # Health check to warm up the server
                 result = await health_check_all(_BASE_URL)
-                if result["status"] != "healthy":
+                if result["status"] != "healthy" and result["status"] != "ok":
                     raise RuntimeError(f"Services unhealthy: {result['message']}")
 
                 _VALIDATED = True
@@ -913,14 +913,14 @@ class Dominus:
 
         # Validate on first call
         if not _VALIDATED:
-            from .helpers.core import verify_token_with_server, health_check_all
+            from .helpers.core import verify_token_format, health_check_all
 
-            # Verify token
-            await verify_token_with_server(_TOKEN, _BASE_URL)
+            # Basic token format check
+            verify_token_format(_TOKEN)
 
-            # Health check
+            # Health check to warm up the server
             result = await health_check_all(_BASE_URL)
-            if result["status"] != "healthy":
+            if result["status"] != "healthy" and result["status"] != "ok":
                 raise RuntimeError(f"Services unhealthy: {result['message']}")
 
             _VALIDATED = True
